package Data::Object::Func::Float;

use Data::Object 'Class';

extends 'Data::Object::Func';

# BUILD
# METHODS

1;

=encoding utf8

=head1 NAME

Data::Object::Func::Float

=cut

=head1 ABSTRACT

Functions for Float Data

=cut

=head1 SYNOPSIS

  use Data::Object::Func::Float;

=cut

=head1 DESCRIPTION

Data::Object::Func::Float is an abstract base class for function classes in the
Data::Object::Func::Float space.

=cut
